Revision: 7139
Author:   ek.kato
Date:     Mon Jun 13 18:52:31 2011
Log:      * gtk2/toolbar/common-gtk.c (toolbar_new) : Check
  uim-toolbar-save-default-im? variable in ~/.uim to use
  uim-custom.

http://code.google.com/p/uim/source/detail?r=7139

Modified:
 /trunk/gtk2/toolbar/common-gtk.c

=======================================
--- /trunk/gtk2/toolbar/common-gtk.c    Mon May 30 22:45:46 2011
+++ /trunk/gtk2/toolbar/common-gtk.c    Mon Jun 13 18:52:31 2011
@@ -1034,15 +1034,14 @@
   GList *prop_buttons = NULL;
   GtkSizeGroup *sg;

-#if 0
   /*
    * Please enable this if you'd like to save default IM into
  * ~/.uim.d/custom/custom-global.scm upon system global IM switch. However, - * using uim-custom consumes quite amount of memory, and requires additional
    * startup time.
    */
-  custom_enabled = (gboolean)uim_custom_enable();
-#endif
+  if (uim_scm_symbol_value_bool("uim-toolbar-save-default-im?"))
+    custom_enabled = (gboolean)uim_custom_enable();

   helper_toolbar_check_custom();
   init_icon();
@@ -1034,15 +1034,14 @@
   /*
-   * Please enable this if you'd like to save default IM into
- * ~/.uim.d/custom/custom-global.scm upon system global IM switch. However, - * using uim-custom consumes quite amount of memory, and requires additional
-   * startup time.
+ * Set uim-toolbar-save-default-im? #t in ~/.uim enable this if you'd like to + * save default IM into ~/.uim.d/custom/custom-global.scm upon system global + * IM switch. However, using uim-custom consumes quite amount of memory, and
+   * requires additional startup time.
    */

Reply via email to